/**
 * Copyright 2010 Marko Lavikainen
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.contextfw.web.application.internal.configuration;


public class RangedIntegerPropertyImpl extends BasicSettableProperty<Integer> {

    private final int min;
    private final int max;
    
    public RangedIntegerPropertyImpl(String key, int min, int max) {
        super(key);
        this.min = min;
        this.max = max;
    }

    @Override
    public Integer validate(Integer value) {
        if (value == null) {
            throw new IllegalArgumentException("Property '"+getKey()+"' cannot be null");
        }
        if (value < min) {
            throw new IllegalArgumentException("Property '"+getKey()+"' was too small: " 
                    + value + " < " + min);
        }
        if (value > max) {
            throw new IllegalArgumentException("Property '"+getKey()+"' was too big: " 
                    + value + " > " + max);
        }
        return value;
    }
}
